import { TransactionReceipt, EventLog } from 'web3-core';
import { Configuration, BlockchainDataModelEntity } from '@energyweb/utils-general';
export interface ICertificate {
    id: string;
    issuer: string;
    deviceId: string;
    generationStartTime: number;
    generationEndTime: number;
    energy: number;
    creationTime: number;
    sync(): Promise<ICertificate>;
    isClaimed(): Promise<boolean>;
    claim(amount: number): Promise<TransactionReceipt>;
    transfer(to: string, amount: number): Promise<TransactionReceipt>;
    getAllCertificateEvents(): Promise<EventLog[]>;
    isOwned(byAddress?: string): Promise<boolean>;
    ownedVolume(byAddress?: string): Promise<number>;
    isClaimed(byAddress?: string): Promise<boolean>;
    claimedVolume(byAddress?: string): Promise<number>;
}
export declare const getAllCertificateEvents: (certId: number, configuration: Configuration.Entity<any, any, any, any>) => Promise<EventLog[]>;
export declare class Entity extends BlockchainDataModelEntity.Entity implements ICertificate {
    isPrivate: boolean;
    deviceId: string;
    generationStartTime: number;
    generationEndTime: number;
    issuer: string;
    energy: number;
    creationTime: number;
    initialized: boolean;
    data: number[];
    constructor(id: string, configuration: Configuration.Entity, isPrivate?: boolean);
    sync(): Promise<Entity>;
    claim(amount: number): Promise<TransactionReceipt>;
    transfer(to: string, amount: number): Promise<TransactionReceipt>;
    revoke(): Promise<TransactionReceipt>;
    getAllCertificateEvents(): Promise<EventLog[]>;
    isOwned(byAddress?: string): Promise<boolean>;
    ownedVolume(byAddress?: string): Promise<number>;
    isClaimed(byAddress?: string): Promise<boolean>;
    claimedVolume(byAddress?: string): Promise<number>;
}
export declare const createCertificate: (to: string, value: number, fromTime: number, toTime: number, deviceId: string, configuration: Configuration.Entity<any, any, any, any>, isVolumePrivate?: boolean) => Promise<Entity>;
export declare function claimCertificates(certificateIds: string[], configuration: Configuration.Entity): Promise<TransactionReceipt>;
export declare function transferCertificates(certificateIds: string[], to: string, configuration: Configuration.Entity): Promise<TransactionReceipt>;
